GS1Barcode class

Constructors

GS1Barcode({required Code code, required Map<String, GS1ParsedElement> elements})
const

Properties

AIs → Iterable<String>
Get available AIs
no setter
code → Code
Barcode description
final
elements → Map<String, GS1ParsedElement>
Map of parsed AI elements. Key - AI string, value - parsed element
final
getAIsData → Map<String, dynamic>
Get all parsed AI elements data
no setter
getAIsParsedElement → Map<String, GS1ParsedElement>
Get all AI elements
no setter
getAIsRawData → Map<String, String>
Get all raw AI elements data
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAIData(String ai) → dynamic
Get parser AI element data
getAIParsedElement(String ai) → GS1ParsedElement?
Get AI element
getAIRawData(String ai) → String?
Get raw AI element data
hasAI(String ai) → bool
Checking for availability AI
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited