GS1BarcodeParserConfig class

Constructors

GS1BarcodeParserConfig({bool allowEmptyPrefix = true, String groupSeparator = DEFAULT_GROUP_SEPARATOR, Map<String, AI> customAIs = const {}})

Properties

allowEmptyPrefix → bool
Allow empty prefix for barcode see Code
final
customAIs → Map<String, AI>
final
groupSeparator → String
Group separator. Default 0xE8
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

DEFAULT_FNC1 → const String
DEFAULT_GROUP_SEPARATOR → const String