GS1ParsedElement<T> class

Constructors

GS1ParsedElement({required String aiCode, String iso = '', required String rawData, required T data})
const

Properties

aiCode → String
AI code
final
data → T
parsed data element
final
hashCode → int
The hash code for this object.
no setterinherited
iso → String
ISO data (currency, country)
final
rawData → String
raw data element
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited